Changelog
=========

2020.1.0
--------

:date: 2020-01-16

* Improved Python 3 compatibility.

2019.11.0
----------

:date: 2019-11-18

* First release with Redash ==> Iodide integration "Explore in Iodide" as
  extracted from redash-stmo.
